import Store from '@/store';
import { $EventBus } from '@/utils/EventBus';
export default {
  getLocation(callback) {
    let _this = this;
    return uni.getLocation({
      type: 'gcj02', //返回可以用于uni.openLocation的经纬度
      success: function (res) {
        var params = {
          lat: res.latitude,
          lng: res.longitude,
        };
        Store.commit('saveLocation', params);
        uni.setStorage({ key: 'location', data: params });
        callback && callback(params);
        //  return params;
      
      },
      fail: function (res) {
        uni.showToast({
          title: '获取地址失败，将导致部分功能不可用',
          icon: 'none',
        });
      },
    });
  },
  // 获取默认店铺
  getAddress(params) {
    return uni.$u.http
      .get('/weixin/getShop', {
        params,
      })
      .then((res) => {
        if (res.data.code == 200) {
          Store.commit('saveShopInfo', res.data.data);
          uni.setStorage({ key: 'shopData', data: res.data.data });
          if (res.data.data) {
            
            $EventBus.$emit('getMenuList', res.data.data);
          }
        }
        return res;
      })
      .catch((err) => {
        return err;
      });
  },
  uniLogin(res, callback) {
    uni.login({
      provider: 'weixin',
      success: function (data) {
        //   传给后台接口所需登录数据
        uni.$u.http
          .post('/weixin/login', {
            code: data.code,
            source: 3,
            iv: res.iv,
            encryptedData: res.encryptedData,
          })
          .then((res) => {
            const { statusCode, data } = res;
            const { code, token, phoneNumber } = data;
            if (statusCode == 200 && data && code == 200) {
              uni.setStorage({ key: 'Authorization', data: token });
              uni.setStorage({ key: 'phoneNumber', data: phoneNumber });
              uni.setStorage({ key: 'userInfo', data: data });
              Store.commit('setUserInfo', data);
              Store.commit('setAuthorization', token);
			  if(callback)
				callback();
            }
          })
          .catch((err) => {
            uni.showToast({
              title: err.msg,
            });
          });
      },
    });
  },
  getAuthorization(phoneNumber) {
    uni.$u.http.post('/weixin/refreshToken ', { phoneNumber }).then((res) => {
      const { data } = res;
      uni.setStorage({ key: 'Authorization', data: data.token });
      Store.commit('setAuthorization', data.token);
      uni.showToast({ title: '登录成功！' });
    });
  },
  // 手机号授权登录
  getPhoneNumber(res, callback) {
    uni.setStorage({ key: 'userPhoneInfo', data: res });
    Store.commit('setUserPhoneInfo', res);
    uni.setStorage({ key: 'phoneInfo', data: res });
    this.uniLogin(res.detail, callback);
  },
  setAllow(allow) {
    uni.$u.http
      .get('/system/customer/allow', {
        params: {
          allow,
        },
      })
      .then((res) => {
        return res;
      })
      .catch((err) => {
        uni.showToast({ title: '服务器错误', icon: 'none' });
      });
  },
};
